==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Tasks.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Defines project tasks.
 * <p>
 * Tasks extend the projen CLI by adding subcommands to it. Task definitions are
 * synthesized into <code>.projen/tasks.json</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.450Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Tasks")
public class Tasks extends io.github.cdklabs.projen.Component {

    protected Tasks(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tasks(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        MANIFEST_FILE = software.amazon.jsii.JsiiObject.jsiiStaticGet(io.github.cdklabs.projen.Tasks.class, "MANIFEST_FILE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Tasks(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Adds global environment.
     * <p>
     * @param name Environment variable name. This parameter is required.
     * @param value Value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addEnvironment(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addEnvironment", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) Adds a task to a project.
     * <p>
     * @param name The name of the task. This parameter is required.
     * @param options Task options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task addTask(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TaskOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required"), options });
    }

    /**
     * (experimental) Adds a task to a project.
     * <p>
     * @param name The name of the task. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task addTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "addTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Removes a task from a project.
     * <p>
     * @return The `Task` that was removed, otherwise `undefined`.
     * @param name The name of the task to remove. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task removeTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "removeTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Finds a task by name.
     * <p>
     * Returns <code>undefined</code> if the task cannot be found.
     * <p>
     * @param name The name of the task. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task tryFind(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFind", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) The project-relative path of the tasks manifest file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static java.lang.String MANIFEST_FILE;

    /**
     * (experimental) All tasks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.Task> getAll() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "all", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class))));
    }

    /**
     * (experimental) Returns a copy of the currently global environment for this project.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> getEnv() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "env", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Tasks.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Defines project tasks.
 * <p>
 * Tasks extend the projen CLI by adding subcommands to it. Task definitions are
 * synthesized into <code>.projen/tasks.json</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.159Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Tasks")
public class Tasks extends io.github.cdklabs.projen.Component {

    protected Tasks(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tasks(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Tasks(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Adds global environment.
     * <p>
     * @param name Environment variable name. This parameter is required.
     * @param value Value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addEnvironment(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addEnvironment", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) Adds a task to a project.
     * <p>
     * @param name The name of the task. This parameter is required.
     * @param options Task options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task addTask(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TaskOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required"), options });
    }

    /**
     * (experimental) Adds a task to a project.
     * <p>
     * @param name The name of the task. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task addTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "addTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Removes a task from a project.
     * <p>
     * @return The <code>Task</code> that was removed, otherwise <code>undefined</code>.
     * @param name The name of the task to remove. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task removeTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "removeTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Synthesizes files to the project output directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void synthesize() {
        software.amazon.jsii.Kernel.call(this, "synthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Finds a task by name.
     * <p>
     * Returns <code>undefined</code> if the task cannot be found.
     * <p>
     * @param name The name of the task. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task tryFind(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFind", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) All tasks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.Task> getAll() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "all", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class))));
    }

    /**
     * (experimental) Returns a copy of the currently global environment for this project.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> getEnv() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "env", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}
